@@ -9,19 +9,38 @@ import shutil
 
 
 # will return the content of a directory (full paths)
-def get_dir_content(dir_path, ignored_files_arr=['.DS_Store']):
-    f = []
+def get_dir_content(dir_path, recursive=False, collect_dirs=True, collect_files=True, ignored_files_arr=['.DS_Store']):
+    f_list = []
+    d_list = []
     for path, dirs, files in os.walk(dir_path):
-        for filename in files:
-            f.append(os.path.join(path, filename))
+        if collect_dirs:
+            if not recursive:
+                d_list = append_path_to_file_list(dir_path, dirs)
+                if collect_files:
+                    f_list = append_path_to_file_list(dir_path, files)
+                break
+            d_list += append_path_to_file_list(dir_path, dirs)
+        if collect_files:
+            if not recursive:
+                f_list = append_path_to_file_list(dir_path, files)
+                break
 
-    f = list(filter(lambda x: get_file_name_from_path(x) not in ignored_files_arr, f))
-    return f
+            f_list += append_path_to_file_list(dir_path, files)
 
-# will return the dirs of a directory (full paths)
-def get_dirs_from_dir(dir_path):
-    for path, dirs, files in os.walk(dir_path):
-        return dirs
+    f_list = list(filter(lambda x: get_file_name_from_path(x) not in ignored_files_arr, f_list))
+    if f_list:
+        if d_list:
+            return [d_list, f_list]
+        return f_list
+    return d_list
+
+
+# will append a base path to every file in a file list
+def append_path_to_file_list(base_path, file_list):
+    full_path_file_list = []
+    for file in file_list:
+        full_path_file_list.append(os.path.join(base_path, file))
+    return full_path_file_list
 
 
 # will return the name of the last dir name from a path
@@ -49,7 +68,7 @@ def get_file_name_from_path(file):
 
 # will remove a directory
 def remove_dir(path):
-    if (os.path.isdir(path)):
+    if os.path.isdir(path):
         shutil.rmtree(path)
 
 
